# Responding to Surveys
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/responding-to-surveys#introduction)
  * [Accessing the Survey Response Form](https://help.sap.com/docs/leanix/ea/responding-to-surveys#accessing-the-survey-response-form)
  * [Accessing Survey from the Dashboard](https://help.sap.com/docs/leanix/ea/responding-to-surveys#accessing-survey-from-the-dashboard)
  * [Responding to Surveys](https://help.sap.com/docs/leanix/ea/responding-to-surveys#responding-to-surveys)


Responding to surveys is crucial for providing feedback on enterprise architecture. Access surveys via the collaboration tab, fact sheets, or dashboard. Learn how to fill them and provide your insights.
